@@ -47,28 +47,18 @@ const char *ScriptChecks::chkUse(Line *line, ScriptImage *img)
 
 const char *ScriptChecks::chkRestart(Line *line, ScriptImage *img)
 {
-	const char *cp = getMember(line);
-	const char *list = gotoMembers();
-
-	if(!cp)
-		return NULL;
-
-	if(!list)
+	if(getMember(line))
 		return "member not used in this command";
 
-	if(!useMember(line, list))
-		return "unknown member used in this command";
-	
 	return chkNoArgs(line, img);
 }
 
 const char *ScriptChecks::chkCall(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	const char *list = gotoMembers();
 	unsigned idx = 0;
 
-	if(cp && !list)
+	if(cp)
 		return "members not used in this command";
 
 	cp = getOption(line, &idx);
@@ -122,14 +112,10 @@ const char *ScriptChecks::chkLock(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkSignal(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	const char *list = gotoMembers();
 
-	if(cp && !list)
+	if(cp)
 		return "member not used in this command";
 
-	if(!useMember(line, list))
-		return "unknown member used in this command";
-
 	if(!line->argc)
 		return "target handler missing";
 
@@ -146,14 +132,10 @@ const char *ScriptChecks::chkSignal(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkThrow(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	const char *list = gotoMembers();
 
-	if(cp && !list)
+	if(cp)
 		return "member not used in this command";
 
-	if(!useMember(line, list))
-		return "unknown member used in this command";
-
 	if(!line->argc)
 		return "target handler missing";
 
@@ -178,14 +160,10 @@ const char *ScriptChecks::chkLabel(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkGoto(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	const char *list = gotoMembers();
 
-	if(cp && !list)
+	if(cp)
 		return "member not used in this command";
 
-	if(!useMember(line, list))
-		return "unknown member used in this command";
-	
 	if(!line->argc)
 		return "target label missing";
 
@@ -202,13 +180,9 @@ const char *ScriptChecks::chkGoto(Line *line, ScriptImage *img)
 const char *ScriptChecks::chkReturn(Line *line, ScriptImage *img)
 {
 	const char *cp = getMember(line);
-	const char *list = gotoMembers();
 
-	if(cp && !list)
+	if(cp)
 		return "member not used in this command";
-
-	if(!useMember(line, list))
-		return "unknown member used in this command";
 	
 	return NULL;
 }
@@ -480,6 +454,20 @@ const char *ScriptChecks::chkAllVars(Line *line, ScriptImage *img)
 	return chkHasArgs(line, img);
 }
 
+const char *ScriptChecks::chkType(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "type does not use member";
+
+	if(hasKeywords(line))
+		return "type does not use keyword";
+
+	if(line->argc < 1)
+		return "type requires at least one var";	
+
+	return chkAllVars(line, img);
+}
+
 const char *ScriptChecks::chkFirstVar(Line *line, ScriptImage *img)
 {
 	const char *cp;
