@@ -733,6 +733,17 @@ repname1:
 				name = token + 2;
 				break;
 			}
+			
+			if(cmds->ripple && *token == '[')
+			{
+				name = token + 1;
+				cp = strchr(name, ']');
+				if(cp)
+					*cp = 0;
+				token = "::";
+				break;
+			}
+
 			tlen = (int)strlen(token);
 			if(token[tlen - 1] == ':')
 			{
@@ -1078,7 +1089,7 @@ repname1:
 
 	if(!scrStream->eof())
 	{
-		if(strstr(name, "::"))
+		if(strstr(name, "::") || cmds->ripple)
 			snprintf(namebuf, sizeof(namebuf), "%s", name);
 		else
 			snprintf(namebuf, sizeof(namebuf), "%s::%s", basename, name);
