@@ -170,7 +170,7 @@ bool ScriptInterp::execute(Method method)
 	return (this->*(method))();
 }
 
-void ScriptInterp::branching(const char *id)
+void ScriptInterp::branching(void)
 {
 }
 
@@ -224,14 +224,17 @@ ScriptSymbols *ScriptInterp::getLocal(void)
 bool ScriptInterp::setConst(const char *id, const char *value)
 {
 	MutexLock lock(*this);
-	Symbol *sym = mapSymbol(id, (unsigned short)strlen(value));
+	Symbol *sym;
+	unsigned short len = (unsigned short)strlen(value);
+
+	sym = mapSymbol(id, len);
 
 	if(!sym)
 		return false;
 
 	if(sym->type != symINITIAL)
 		return false;
-	
+
 	sym->type = symCONST;
 	setString(sym->data, sym->size + 1, value);
 	return true;
@@ -312,7 +315,7 @@ retry:
 		if(!id[count])
 			break;
 
-		if(!strchr("abcdefghijklmnopqrstuvwxyz01234567890.", tolower(id[count])))
+		if(!strchr("abcdefghijklmnopqrstuvwxyz01234567890._", tolower(id[count])))
 		{
 			logmissing(id, "invalid");
 			return NULL;
@@ -549,6 +552,8 @@ bool ScriptInterp::tryCatch(const char *id)
 	if(!scr || !push())
 		return false;
 
+	branching();
+
 	frame[stack].script = scr;
 	frame[stack].line = frame[stack].first = scr->first;
 	frame[stack].caseflag = frame[stack].tranflag = 0;
@@ -561,6 +566,7 @@ bool ScriptInterp::tryCatch(const char *id)
 void ScriptInterp::gotoEvent(NamedEvent *evt)
 {
         clearStack();
+	branching();
         frame[stack].tranflag = frame[stack].caseflag = false;
         frame[stack].line = frame[stack].first = evt->line;
         image->fastBranch(this);
@@ -1171,6 +1177,7 @@ bool ScriptInterp::signal(const char *trapname)
 
 //	stop(mask);
 	trap(trapname);
+	branching();
 
 	image->fastBranch(this);
 	return true;
@@ -1203,12 +1210,12 @@ bool ScriptInterp::signal(unsigned id)
 //	stop(mask);
 
 	trap(id);
+	branching();
 
 	image->fastBranch(this);
 	return true;
 }
 
-
 const char *ScriptInterp::hasOption(void)
 {
 	for(;;)
