@@ -279,6 +279,25 @@ unsigned Script::count(Symbol *sym)
 	}
 }
 
+unsigned Script::storage(Symbol *sym)
+{
+	Array *a = (Array *)&sym->data;
+
+	switch(sym->type)
+	{
+	case symARRAY:
+	case symSTACK:
+	case symFIFO:
+		return a->rec;
+	case symPROPERTY:
+		return sym->size - sizeof(ScriptProperty *);
+	case symINITIAL:
+	case symNORMAL:
+		return sym->size;		
+	}
+	return 0;
+}
+
 const char *Script::extract(Symbol *sym)
 {
         long value;
