@@ -248,6 +248,7 @@ public:
 	static bool symindex(Symbol *sym, short offset);
 	static const char *extract(Symbol *sym);
 	static unsigned count(Symbol *sym);
+	static unsigned storage(Symbol *sym);
 	static void clear(Symbol *sym);
 	static char decimal;
 	static const char *plugins;
@@ -326,8 +327,8 @@ private:
 	Keyword *keywords[SCRIPT_INDEX_SIZE];
 	char *traps[TRAP_BITS];
 	ScriptImage *active;
-	int keyword_count;
-	int trap_count;
+	unsigned keyword_count;
+	unsigned trap_count;
 	unsigned long imask;
 	unsigned dbcount;
 	void *dbc;
@@ -340,6 +341,15 @@ protected:
 	virtual const char *getExternal(const char *opt);
 
 public:
+	/**
+	 * Checks if the line statement is an input statement.  Used in
+	 * some servers...
+	 *
+	 * @return true if line is input.
+	 * @param line to examine.
+	 */
+	virtual bool isInput(Line *line);
+
 	/**
 	 * Get the method handler associated with a given keyword.  This
 	 * is used by ScriptImage when compiling.
@@ -366,6 +376,14 @@ public:
 	inline ScriptImage *getActive(void)
 		{return active;};
 
+	/**
+	 * Get the name of a trap from it's id.
+	 *
+	 * @param id of trap.
+	 * @return name of trap.
+	 */
+	const char *getTrapName(unsigned id);
+
 protected:
 	/**
 	 * Fetch whether the given keyword is valid for constructor.
@@ -498,13 +516,6 @@ protected:
 	 */
 	bool useMember(Line *line, const char *list);
 
-	/**
-	 * Members permitted in goto, see branching virtual in interp.
-	 *
-	 * @return list of valid members for useMember check.
-	 */
-	virtual const char *gotoMembers(void);
-
 	/**
 	 * Get an option to examine.
 	 *
@@ -538,7 +549,7 @@ protected:
 	 *
 	 * @return count of active trap identifiers.
 	 */
-	inline int getCount(void)
+	inline unsigned getCount(void)
 		{return trap_count;};
 
 	/**
@@ -651,6 +662,14 @@ public:
 	 */
 	const char *chkFirstVar(Line *line, ScriptImage *img);
 
+	/**
+	 * A basic type check for simple type declarations...
+	 *
+	 * @return syntax error message string or NULL.
+	 * @param line statement.
+	 */
+	const char *chkType(Line *line, ScriptImage *img);
+
 	/**
 	 * Script compiler syntax check for certain variable using
 	 * statements such as "clear".  Assumes list of valid variable
@@ -1386,13 +1405,10 @@ public:
 
 	/**
 	 * A virtual holding a branch conditional member.  This may be
-	 * invoked typically from goto or restart.  It might be used to
-	 * pass a "clear" or "cleardigits" option in Bayonne, or any
-	 * generic option chosen in a derived engine.
-	 *
-	 * @param option from branching getMember().
+	 * invoked typically from goto or restart.  Can be used to check
+	 * contextual changes.
 	 */
-	virtual void branching(const char *option);
+	virtual void branching(void);
 
 	inline bool isRunning(void)
 		{return (image != NULL) && initialized;};
